import cors from 'cors'; // Node.js package for providing a Connect/Express middleware that can be used to enable CORS with various options...
import express, {NextFunction, Request, Response} from 'express';
// 'index.ts' file is imported and contained code is executed:
import './persistence'; // Make database accessible and running...
import {corsMethods, corsUrl, port} from './Configuration';
import {router} from './services'; // Look at 'index.ts' by default...

export const API = express();
API.use(express.json()); // 'application/json' parsing...
API.use(express.urlencoded({extended: false})); // 'application/x-www-form-urlencoded' parsing...
API.use(cors({origin: corsUrl, methods: corsMethods})); // CORS enabling...
// Load the API:
API.use('/NYCP/API', router); // Main router...
// '404' type error:
API.use((request, response) => {
    response.status(404).json({message: 'Error 404, page not found...'});
})
// '500' type error:
API.use((err: Error, request: Request, response: Response, next: NextFunction) => {
    response.status(500).json({...err, message: err.message});
});

API.set('port', port);
API.listen(port, () => {
    console.log(`/NYCP/API is running on port: ${port}`);


    API._router.stack          // registered routes
        .filter((r: any) => r.route)    // take out all the middleware
        .map((r: any) => console.log(r.route.path));


}).on('error', error => console.log(error.message));
