import * as Mongoose from "mongoose";

export default interface CriminalCase extends Mongoose.Document {
    criminal_case_number: string;
    jurisdiction_name: string;
    date_of_criminal_case: Date;
}
// create table CRIMINAL_CASE(
//     CRIMINAL_CASE_NUMBER varchar(10),
//     JURISDICTION_NAME varchar(30),
//     DATE_OF_CRIMINAL_CASE Date,
//     constraint CRIMINAL_CASE_key primary key(CRIMINAL_CASE_NUMBER,JURISDICTION_NAME));
const schema = new Mongoose.Schema(
    {
        criminal_case_number: {
            type: Mongoose.Schema.Types.String,
            required: true,
            maxlength: 10
        },
        jurisdiction_name: {
            type: Mongoose.Schema.Types.String,
            required: true,
            maxlength: 30
        },
        date_of_criminal_case: {
            type: Mongoose.Schema.Types.Date,
            required: true,
            default: Date.now
        }
    }
);
// Primary key (performance issues):
schema.index({'criminal_case_number': 1 /* ascending '1', descending '-1' */, 'jurisdiction_name': 1}, {unique: true});
export const CriminalCaseModel = Mongoose.model<CriminalCase>('CRIMINAL_CASE', schema);
CriminalCaseModel.insertMany([
    {criminal_case_number: 'P64000', jurisdiction_name: 'Pau', date_of_criminal_case: new Date(Date.UTC(2001, 1, 22))},
    {criminal_case_number: 'L69000', jurisdiction_name: 'Lyon', date_of_criminal_case: new Date(Date.UTC(1996, 3, 15))},
    {
        criminal_case_number: 'M13000',
        jurisdiction_name: 'Marseille',
        date_of_criminal_case: new Date(Date.UTC(1993, 11, 6))
    }])
    .then(() => {
        console.log("'CriminalCaseModel.insertMany' OK")
    }).catch(
    (error: Mongoose.CallbackError) => {
        console.log(`'CriminalCaseModel.insertMany' not OK ${error}`);
    }
);
