import * as Mongoose from "mongoose";
import Prisoner from "./Prisoner";

export default interface JudicialDecision extends Mongoose.Document {
    decision_type_number: string;
    prisoner: Prisoner;
    date_of_decision: Date;
}
// create table JUDICIAL_DECISION(
//     DECISION_TYPE_NUMBER varchar(1),
//     PRISON_FILE_NUMBER varchar(10),
//     DATE_OF_DECISION Date,
//     constraint JUDICIAL_DECISION_key primary key(DECISION_TYPE_NUMBER,PRISON_FILE_NUMBER,DATE_OF_DECISION),
//     constraint JUDICIAL_DECISION_fk foreign key(PRISON_FILE_NUMBER) references PRISONER(PRISON_FILE_NUMBER));
const schema = new Mongoose.Schema(
    {
        decision_type_number: {
            type: Mongoose.Schema.Types.String,
            required: true,
            enum: ['1', '2', '3'],
            maxlength: 1
        },
        prisoner: {
            type: Mongoose.Schema.Types.ObjectId,
            required: true,
            ref: 'PRISONER'
        },
        date_of_decision: {
            type: Mongoose.Schema.Types.Date,
            required: true,
            default: Date.now
        }
    },
    // 'discriminatorKey' option tells mongoose to add a path to the schema called 'decision_type_number' so that it tracks which type of document this is:
    {discriminatorKey: 'decision_type_number'}
);
// Primary key (performance issues!):
schema.index({decision_type_number: 1, prisoner: 1, date_of_decision: 1}, {unique: true});
export const JudicialDecisionModel = Mongoose.model<JudicialDecision>('JUDICIAL_DECISION', schema);
/* Conviction */
JudicialDecisionModel.discriminator('1', new Mongoose.Schema(
    {
        duration: {
            type: Mongoose.Schema.Types.Number,
            required: true
        }
    }
));
/* Shortened sentence */
JudicialDecisionModel.discriminator('2', new Mongoose.Schema(
    {
        duration: {
            type: Mongoose.Schema.Types.Number,
            required: true
        }
    }
));
/* Final discharge */
JudicialDecisionModel.discriminator('3', new Mongoose.Schema(
    {
        date_of_final_discharge: {
            type: Mongoose.Schema.Types.Date,
            required: true,
            default: Date.now
        }
    }
));
