import * as Mongoose from "mongoose";

export default interface Motive extends Mongoose.Document {
    motive_number: string;
    motive_label: string;
}
// create table MOTIVE(
//     MOTIVE_NUMBER varchar(10),
//     MOTIVE_LABEL varchar(50) not null,
//     constraint MOTIVE_key primary key(MOTIVE_NUMBER),
//     constraint MOTIVE_unique unique(MOTIVE_LABEL));
const schema = new Mongoose.Schema(
    {
        motive_number: {
            type: Mongoose.Schema.Types.String,
            required: true,
            unique: true,
            index: true, // Primary key...
            maxlength: 10
        },
        motive_label: {
            type: Mongoose.Schema.Types.String,
            required: true,
            unique: true,
            maxlength: 50
        }
    }
);
// Models are fancy constructors compiled from 'Schema' definitions:
export const MotiveModel = Mongoose.model<Motive>('MOTIVE', schema);
// By default, mongoose adds an '_id' property to any schema:
console.assert('_id' in new MotiveModel(), "'_id' in new MotiveModel()");
/** Mongoose automatically looks for the plural, lowercase version of the model name.
 * So, 'MOTIVE' -> 'motives'
 * */
MotiveModel.insertMany([{motive_number: '01', motive_label: 'theft and various misdemeanors'},
    {motive_number: '02', motive_label: 'assault and battery'},
    {motive_number: '03', motive_label: 'fraud'}])
    .then(() => {
        console.log("'MotiveModel.insertMany' OK")
    }).catch(
    (error: Mongoose.CallbackError) => {
        console.log(`'MotiveModel.insertMany' not OK ${error}`);
    }
);
MotiveModel.create([{motive_number: '04', motive_label: 'carrying of a weapon without a license'}])
    .then(() => {
        console.log("'MotiveModel.create' OK")
    }).catch(
    (error: Mongoose.CallbackError) => {
        console.log(`'MotiveModel.create' not OK ${error}`);
    }
);
//     ,
//     (error: Mongoose.CallbackError, docs: Array<Object> | Mongoose.InsertManyResult) => {
//         if (error) console.error(error.message);
//         else console.log(JSON.stringify(docs));
//     }
// );
