import * as Mongoose from "mongoose";
import CriminalCase from "./CriminalCase";
import Motive from "./Motive";

export default interface Prisoner extends Mongoose.Document {
    prison_file_number: string;
    given_name: string;
    surname: string;
    date_of_birth: Date;
    place_of_birth: string;
    date_of_incarceration: Date;
    main: CriminalCase;
    motive: Motive;
    offense: CriminalCase[];
}
// create table PRISONER(
//     PRISON_FILE_NUMBER varchar(10),
//     GIVEN_NAME varchar(30),
//     SURNAME varchar(30),
//     DATE_OF_BIRTH Date,
//     PLACE_OF_BIRTH varchar(30),
//     DATE_OF_INCARCERATION Date,
//     CRIMINAL_CASE_NUMBER varchar(10) not null,
//     JURISDICTION_NAME varchar(30) not null,
//     MOTIVE_NUMBER varchar(10) not null,
//     constraint PRISONER_key primary key(PRISON_FILE_NUMBER),
//     constraint INCARCERATION_MAIN foreign key(CRIMINAL_CASE_NUMBER,JURISDICTION_NAME) references CRIMINAL_CASE(CRIMINAL_CASE_NUMBER,JURISDICTION_NAME),
//     constraint INCARCERATION_MOTIVE foreign key(MOTIVE_NUMBER) references MOTIVE(MOTIVE_NUMBER));

const schema = new Mongoose.Schema(
    {
        prison_file_number: {
            type: Mongoose.Schema.Types.String,
            required: true,
            unique: true,
            index: true,
            maxlength: 10
        },
        given_name: {
            type: Mongoose.Schema.Types.String,
            // required: true, // For simplication...
            // Remove white spaces:
            trim: true,
            maxlength: 30
        },
        surname: {
            type: Mongoose.Schema.Types.String,
            // required: true, // For simplication...
            // Remove white spaces:
            trim: true,
            maxlength: 30
        },
        date_of_birth: {
            type: Mongoose.Schema.Types.Date,
            // required: true // For simplication...
        },
        place_of_birth: {
            type: Mongoose.Schema.Types.String,
            // required: true, // For simplication...
            // Remove white spaces:
            trim: true,
            maxlength: 30
        },
        date_of_incarceration: {
            type: Mongoose.Schema.Types.Date,
            required: true,
            default: Date.now
        },
        main: {
            type: Mongoose.Schema.Types.ObjectId,
            required: true,
            ref: 'CRIMINAL_CASE'
        },
        motive: {
            type: Mongoose.Schema.Types.ObjectId,
            required: true,
            ref: 'MOTIVE'
        },
        offense: {
            type: [{type: Mongoose.Schema.Types.ObjectId, ref: 'CRIMINAL_CASE'}]
        }
    }
);

export const PrisonerModel = Mongoose.model<Prisoner>('PRISONER', schema);
