import {NextFunction, Request, Response} from 'express';
import Joi from 'joi';
// import {isEmpty} from 'lodash';

export enum ValidationSource {
    BODY = 'body',
    HEADERS = 'headers',
    PARAMS = 'params',
    QUERY = 'query'
}

export default (schema: Joi.ObjectSchema, source: ValidationSource = ValidationSource.QUERY) => (request: Request, response: Response, next: NextFunction) => {
    try {
        /* Validate 'request' content (body, etc.) */
        // DEBUG:
        // isEmpty(request[source]) ?
        //     console.log(`Validator ${source}: no data`) :
        //     console.log(`Validator ${source}: ` + JSON.stringify(request[source]));
        // '{abortEarly: false}' means after the last validation error:
        const {error} = schema.validate(request[source], {abortEarly: false});
        // 'next' function when invoked within an Express router executes the middleware succeeding the current middleware:
        if (!error) return next();
        next(error);
    } catch (error) {
        next(error);
    }
};
