import express from 'express';

import {Get_collection_name} from '../../persistence/DAOs/JudicialDecisionDAO';
import {PrisonerModel} from "../../persistence/schemes/Prisoner";

// Mini. app. for '/Under_remand' sub-path:
export const router = express.Router();
// curl http://localhost:1963/NYCP/API/Under_remand
router.get('/', (request, response) => {
    console.log("Use case: " + request.baseUrl + request.path);
    PrisonerModel.aggregate([
        {
            $lookup:
                {
                    from: Get_collection_name(), // Search in 'judicial_decisions' collection...
                    let: {prisoner_id: "$_id"}, // Get '_id' field in 'prisoners' collection...
                    pipeline: [
                        {
                            $match:
                                {
                                    $expr:
                                        { // 'prisoner' field in 'judicial_decisions' collection matches with 'prisoner_id'
                                            $and: [{$eq: ["$decision_type_number", "1"]}, {$eq: ["$prisoner", "$$prisoner_id"]}]
                                        }
                                }
                        }
                    ],
                    as: "convictions"
                }
        },
        // Only keep those for whom 'convictions' array (added) field is empty, i.e., no conviction yet...
        {$match: {convictions: {$size: 0}}},
        // Only 'prison_file_number' data...
        {$project: {_id: false, prison_file_number: true}}
    ]).then(data => response.status(200).json(data))
        .catch(error => response.status(400).json({error, message: error.message}));
});
